/**
 * @file
 * Initializes all Recombee Public Scenario blocks.
 */

(function ($, Drupal) {

  'use strict';

  Drupal.behaviors.recombeePublicScenario = {
    attach: function attach(context, settings) {

      if (typeof settings.recombeePublicScenario === 'undefined') {
        return;
      }

      $.each(settings.recombeePublicScenario, function (id, args) {
        var element = $('#' + id, context);
        if (element.length) {
          console.debug('Recombee: Initialization of "' + id + '".');
          var client = getClient(args.accountId, args.publicToken);
          if (typeof client !== 'undefined') {
            var template = settings.recombeeTemplate[args.template];
            var itemId = getItemId();
            var userId = getUserId();
            getRecommendations(element, client, template, itemId, userId, args);
          }
          else {
            console.error('Recombee: Client not available.');
          }
        }
      });

      function getItemId() {
        if (typeof window['RecombeeItemId'] === 'function') {
          return window['RecombeeItemId']();
        }
        return getDefaultItemId();
      }

      function getDefaultItemId() {
        var $itemIdMeta = $('meta[name="recombee-item-id"]');
        if ($itemIdMeta.length) {
          return $itemIdMeta.attr('content');
        }
        else {
          console.debug('Recombee: Meta item ID not available.');
        }
      }

      function getUserId() {
        if (typeof window['RecombeeUserId'] === 'function') {
          return window['RecombeeUserId']();
        }
        return getDefaultUserId();
      }

      function getDefaultUserId() {
        var value = $.cookie('RecombeeUserId');
        if (typeof value === 'undefined') {
          var arr = new Uint8Array(10);
          (window.crypto || window.msCrypto).getRandomValues(arr);
          value = '';
          for (var i = 0; i < arr.length; i++) {
            value += ('0' + arr[i].toString(16)).substr(-2);
          }
          $.cookie('RecombeeUserId', value, { expires: 365 });
        }
        return value;
      }

      function getClient(databaseId, token) {
        if (typeof databaseId === 'undefined') {
          console.debug('Recombee: Database ID not available.');
        }
        else if (typeof token === 'undefined') {
          console.debug('Recombee: Public token not available.');
        }
        else {
          return new recombee.ApiClient(databaseId, token);
        }
      }

      function getRecommendations(block, client, template, itemId, userId, args) {
        var options = {
          scenario: args.scenario,
          returnProperties: true,
        };
        var interaction = null;
        switch (args.endpoint) {
          case 'items-to-item':
            if (typeof itemId !== 'undefined') {
              interaction = new recombee.RecommendItemsToItem(itemId, userId, args.pageSize, options);
            }
            else {
              console.error('Recombee: Recommendation item ID not available.');
            }
            break;
          case 'items-to-user':
            if (typeof userId !== 'undefined') {
              interaction = new recombee.RecommendItemsToUser(userId, args.pageSize, options);
            }
            else {
              console.error('Recombee: Recommendation user ID not available.');
            }
            break;
          default:
            console.error('Recombee: Interaction "' + args.endpoint + '" not available.');
            break;
        }
        if (interaction) {
          client.send(interaction)
            .then(renderRecommendations(block, template))
            .catch(function (error) {
              console.error('Recombee: ' + error);
            });
        }
      }

      function renderRecommendations(block, source) {
        return function (result) {
          var template = Handlebars.compile(source);
          block.html(template(result));
        }
      }

    }
  };

})(jQuery, Drupal);
