<?php

namespace Drupal\recombee\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\recombee\RecombeeTemplateInterface;

/**
 * Defines the Recombee template configuration entity.
 *
 * @ConfigEntityType(
 *   id = "recombee_template",
 *   label = @Translation("Recombee template"),
 *   label_collection = @Translation("Recombee templates"),
 *   label_singular = @Translation("Recombee template"),
 *   label_plural = @Translation("Recombee templates"),
 *   handlers = {
 *     "form" = {
 *       "default" = "Drupal\recombee\Form\RecombeeTemplateForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm",
 *     },
 *     "list_builder" = "Drupal\recombee\RecombeeTemplateListBuilder",
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     },
 *   },
 *   admin_permission = "administer recombee templates",
 *   config_prefix = "template",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "markup",
 *   },
 *   links = {
 *     "collection" = "/admin/config/search/recombee/templates",
 *     "add-form" = "/admin/config/search/recombee/templates/add",
 *     "edit-form" = "/admin/config/search/recombee/templates/{recombee_template}/edit",
 *     "delete-form" = "/admin/config/search/recombee/templates/{recombee_template}/delete",
 *   },
 * )
 */
class RecombeeTemplate extends ConfigEntityBase implements RecombeeTemplateInterface {

  /**
   * The Recombee template machine name.
   *
   * @var string
   */
  protected $id;

  /**
   * The human-readable name of the Recombee template entity.
   *
   * @var string
   */
  protected $label;

  /**
   * The Recombee template markup.
   *
   * @var string
   */
  protected $markup;

  /**
   * {@inheritdoc}
   */
  public function getMarkup() {
    return $this->markup;
  }

  /**
   * {@inheritdoc}
   */
  public function setMarkup($markup) {
    $this->markup = $markup;
    return $this;
  }

}
